##################################################################################
#                                 _             _
#                                | |_  ___ _ __(_)__ _
#                                | ' \/ -_) '_ \ / _` |
#                                |_||_\___| .__/_\__,_|
#                                         |_|
#
##################################################################################
#
# Company: hepia
# Author: Orphee Antoniadis <orphee.antoniadis@hesge.ch>
#
# Project Name: scalp_mipi
# Target Device: hepia-cores.ch:scalp_node:part0:0.1 xc7z015clg485-2
# Tool version: 2020.2
# Description: TCL script for re-creating Vitis workspace
#
# Last update: 2021-04-28 16:21:16
#
##################################################################################

#
# Include files
#
source utils.tcl

#
# Procedures
#
# Create source directories and import application source files
proc import_app_sources {prj_workspace app_name app_src_path} {
	puts "Import application source file into workspace..."

	# Create workspace application directory
	set ws_app_src_dir "${prj_workspace}/${app_name}/src"
	file mkdir "${ws_app_src_dir}"
	print_status "Create app directory into workspace: ${ws_app_src_dir}" "OK"

	foreach f [glob -nocomplain -directory ${app_src_path} *] {
		file copy -force $f ${ws_app_src_dir}
		print_status "Copy $f into ${ws_app_src_dir}" "OK"
	}
}

#
# Generate workspace
#

# Set variables
set pwd [pwd]

set prj_workspace "../vitis_workspace"

set prj_platform "scalp_mipi"
set prj_desc "Zynq platform project"
set prj_xsa "${pwd}/../hw_export/scalp_mipi.xsa"

# Generate default application for APU0
# APU0 - Cortex-A9
set apu_0_prj_proc "ps7_cortexa9_0"
set apu_0_prj_os "standalone"

set apu_0_domain_name "standalone_apu0_domain"

set apu_0_app_sysprj "scalp_mipi_app_system"
set apu_0_app_template "Empty Application"

set apu_0_app_name "scalp_mipi_app"
set apu_0_app_src_dir "${pwd}/../sw_apps/scalp_mipi_app/src"

# Create the workspace
file mkdir $prj_workspace
setws $prj_workspace

# Create the platform from the XSA (Xilinx Shell Archive) file
platform create -name $prj_platform -desc $prj_desc -hw $prj_xsa 

# Create a domain for the APU (Core_0)
domain create -name ${apu_0_domain_name} -proc ${apu_0_prj_proc} -os ${apu_0_prj_os}

# Setup the APU_0 domain
domain active ${apu_0_domain_name}
# Example of how to add libraries to the BSP
#bsp setlib -name xilfpga
#bsp setlib -name xilsecure

# Build the platform
platform active ${prj_platform}
platform generate

# Build the APU_0 domain
domain active ${apu_0_domain_name}
# Create an application for APU Core_0
app create -name ${apu_0_app_name} -sysproj ${apu_0_app_sysprj} -platform ${prj_platform} -domain ${apu_0_domain_name} -proc ${apu_0_prj_proc} -os ${apu_0_prj_os} -template ${apu_0_app_template} -lang {c}
# Add application sources
# Sources are copied into the workspace directory
import_app_sources ${prj_workspace} ${apu_0_app_name} ${apu_0_app_src_dir}
# Set includes path
app config -name ${apu_0_app_name} -add include-path {"${workspace_loc:/${ProjName}/src/inc}"}
# Build application
app build ${apu_0_app_name}
