----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Orphee Antoniadis <orphee.antoniadis@hesge.ch>
--
-- Module Name: scalp_mipi_zynqps_wrapper - arch
-- Target Device: hepia-cores.ch:scalp_node:part0:0.1 xc7z015clg485-2
-- Tool version: 2020.2
-- Description: scalp_mipi_zynqps_wrapper
--
-- Last update: 2021-04-28 16:06:01
--
---------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity scalp_mipi_zynqps_wrapper is

    port (
        -- Processor interface
        FIXED_IO_ps_clk     : inout std_logic;
        FIXED_IO_ps_porb    : inout std_logic;
        FIXED_IO_ps_srstb   : inout std_logic;
        FclkClk0xCO         : out   std_logic;
        FclkReset0xRO       : out   std_logic;
        -- DDR interface
        DDR_addr            : inout std_logic_vector (14 downto 0);
        DDR_ba              : inout std_logic_vector (2 downto 0);
        DDR_cas_n           : inout std_logic;
        DDR_ck_n            : inout std_logic;
        DDR_ck_p            : inout std_logic;
        DDR_cke             : inout std_logic;
        DDR_cs_n            : inout std_logic;
        DDR_dm              : inout std_logic_vector (3 downto 0);
        DDR_dq              : inout std_logic_vector (31 downto 0);
        DDR_dqs_n           : inout std_logic_vector (3 downto 0);
        DDR_dqs_p           : inout std_logic_vector (3 downto 0);
        DDR_odt             : inout std_logic;
        DDR_ras_n           : inout std_logic;
        DDR_reset_n         : inout std_logic;
        DDR_we_n            : inout std_logic;
        FIXED_IO_ddr_vrn    : inout std_logic;
        FIXED_IO_ddr_vrp    : inout std_logic;
        -- USB interface
        Usb0VBusPwrFaultxSI : in    std_logic;
        -- SPI1 used as uWire master. Clk, Data and LE signals are outputs
        -- SPI1 inputs are unused. Clk is connected to SCLK, Data to MOSI and LE to SS
        Spi1MOSIxSO         : out   std_logic;
        Spi1SSxSO           : out   std_logic;
        Spi1SclkxCO         : out   std_logic;
        -- MIO
        FIXED_IO_mio        : inout std_logic_vector (53 downto 0);
        -- Scalp Axi Lite interface and IRQ
        InterruptxSI        : in    std_logic;
        RdAddrxDO           : out   std_logic_vector (11 downto 0);
        RdDataxDI           : in    std_logic_vector (31 downto 0);
        RdValidxSO          : out   std_logic;
        WrAddrxDO           : out   std_logic_vector (11 downto 0);
        WrDataxDO           : out   std_logic_vector (31 downto 0);
        WrValidxSO          : out   std_logic;
        RgbLedsCtrlPortxDO  : out   std_logic_vector (31 downto 0);
        -- Camera GPIOs
        CamPwup             : out   std_logic_vector (0 downto 0);
        CamGpio             : out   std_logic_vector (0 downto 0);
        -- Camera I2C interface
        I2c1SdaxSI          : in    std_logic;
        I2c1SdaxSO          : out   std_logic;
        I2c1SdaxST          : out   std_logic;
        I2c1SclxSI          : in    std_logic;
        I2c1SclxSO          : out   std_logic;
        I2c1SclxST          : out   std_logic;
        -- GPIO0 interface
--        GPIO0xDI            : in    std_logic_vector (31 downto 0);
--        GPIO0xDO            : out   std_logic_vector (31 downto 0);
--        GPIO0xDT            : out   std_logic_vector (31 downto 0);
        -- MIPI interface
        MipiClockHsN        : in    std_logic;
        MipiClockHsP        : in    std_logic;
        MipiClockLpN        : in    std_logic;
        MipiClockLpP        : in    std_logic;
        MipiDataHsN         : in    std_logic_vector (1 downto 0);
        MipiDataHsP         : in    std_logic_vector (1 downto 0);
        MipiDataLpN         : in    std_logic_vector (1 downto 0);
        MipiDataLpP         : in    std_logic_vector (1 downto 0)
--        FakeMipiClockHsN    : in    std_logic;
--        FakeMipiClockHsP    : in    std_logic;
--        FakeMipiClockLpN    : in    std_logic;
--        FakeMipiClockLpP    : in    std_logic;
--        FakeMipiDataHsN     : in    std_logic_vector (1 downto 0);
--        FakeMipiDataHsP     : in    std_logic_vector (1 downto 0);
--        FakeMipiDataLpN     : in    std_logic_vector (1 downto 0);
--        FakeMipiDataLpP     : in    std_logic_vector (1 downto 0);
--        Csi2Rstn            : in    std_logic;
--        DmaRstn             : in    std_logic
);

end scalp_mipi_zynqps_wrapper;

architecture arch of scalp_mipi_zynqps_wrapper is

begin

    ScalpZynqPSxI : entity work.scalp_mipi_zynqps
        port map (
            DDR_addr            => DDR_addr,
            DDR_ba              => DDR_ba,
            DDR_cas_n           => DDR_cas_n,
            DDR_ck_n            => DDR_ck_n,
            DDR_ck_p            => DDR_ck_p,
            DDR_cke             => DDR_cke,
            DDR_cs_n            => DDR_cs_n,
            DDR_dm              => DDR_dm,
            DDR_dq              => DDR_dq,
            DDR_dqs_n           => DDR_dqs_n,
            DDR_dqs_p           => DDR_dqs_p,
            DDR_odt             => DDR_odt,
            DDR_ras_n           => DDR_ras_n,
            DDR_reset_n         => DDR_reset_n,
            DDR_we_n            => DDR_we_n,
            FIXED_IO_ddr_vrn    => FIXED_IO_ddr_vrn,
            FIXED_IO_ddr_vrp    => FIXED_IO_ddr_vrp,
            FIXED_IO_mio        => FIXED_IO_mio,
            FIXED_IO_ps_clk     => FIXED_IO_ps_clk,
            FIXED_IO_ps_porb    => FIXED_IO_ps_porb,
            FIXED_IO_ps_srstb   => FIXED_IO_ps_srstb,
            FclkClk0xCO         => FclkClk0xCO,
            FclkReset0xRO(0)    => FclkReset0xRO,
            Spi1MOSIxSO         => Spi1MOSIxSO,
            Spi1SSxSO           => Spi1SSxSO,
            Spi1SclkxCO         => Spi1SclkxCO,
            Usb0VBusPwrFaultxSI => Usb0VBusPwrFaultxSI,
            InterruptxSI        => InterruptxSI,
            RdAddrxDO           => RdAddrxDO,
            RdDataxDI           => RdDataxDI,
            RdValidxSO          => RdValidxSO,
            WrAddrxDO           => WrAddrxDO,
            WrDataxDO           => WrDataxDO,
            WrValidxSO          => WrValidxSO,
            RgbLedsCtrlPortxDO  => RgbLedsCtrlPortxDO,
            CamPwup             => CamPwup,
            CamGpio             => CamGpio,
            I2C1_SDA_I          => I2c1SdaxSI,
            I2C1_SDA_O          => I2c1SdaxSO,
            I2C1_SDA_T          => I2c1SdaxST,
            I2C1_SCL_I          => I2c1SclxSI,
            I2C1_SCL_O          => I2c1SclxSO,
            I2C1_SCL_T          => I2c1SclxST,
            MIPI_clk_hs_n       => MipiClockHsN,
            MIPI_clk_hs_p       => MipiClockHsP,
            MIPI_clk_lp_n       => MipiClockLpN,
            MIPI_clk_lp_p       => MipiClockLpP,
            MIPI_data_hs_n      => MipiDataHsN,
            MIPI_data_hs_p      => MipiDataHsP,
            MIPI_data_lp_n      => MipiDataLpN,
            MIPI_data_lp_p      => MipiDataLpP
--            FAKEMIPI_clk_hs_n       => FakeMipiClockHsN,
--            FAKEMIPI_clk_hs_p       => FakeMipiClockHsP,
--            FAKEMIPI_clk_lp_n       => FakeMipiClockLpN,
--            FAKEMIPI_clk_lp_p       => FakeMipiClockLpP,
--            FAKEMIPI_data_hs_n      => FakeMipiDataHsN,
--            FAKEMIPI_data_hs_p      => FakeMipiDataHsP,
--            FAKEMIPI_data_lp_n      => FakeMipiDataLpN,
--            FAKEMIPI_data_lp_p      => FakeMipiDataLpP,
--            Csi2Rstn            => Csi2Rstn,
--            DmaRstn             => DmaRstn
            );

end arch;
